@@ -60,7 +60,7 @@
 #' This argument is necessary if you choose the 'predefined' selection.
 #' @param deg_to_metre integer. The conversion rate of metres to degree. See the details section for more information.
 #' @param biomod2 logical. Creates a matrix of folds that can be directly used in the \pkg{biomod2} package as
-#' a \emph{data.split.table} for cross-validation.
+#' a \emph{CV.user.table} for cross-validation.
 #' @param offset two number between 0 and 1 to shift blocks by that proportion of block size.
 #' This option only works when \code{size} is provided.
 #' @param extend numeric; This parameter specifies the percentage by which the map's extent is
@@ -76,7 +76,7 @@
 #'
 #'
 #' @seealso \code{\link{cv_buffer}} and \code{\link{cv_cluster}}; \code{\link{cv_spatial_autocor}} and \code{\link{cv_block_size}} for selecting block size
-#' @seealso For \emph{data.split.table} see \code{\link[biomod2]{BIOMOD_cv}} in \pkg{biomod2} package
+#' @seealso For \emph{CV.user.table} see \code{\link[biomod2]{BIOMOD_Modeling}} in \pkg{biomod2} package
 #'
 #' @references Bahn, V., & McGill, B. J. (2012). Testing the predictive performance of distribution models. Oikos, 122(3), 321-331.
 #'
@@ -369,7 +369,7 @@ cv_spatial <- function(
         train_test_table[p, which(cl %in% names(countrain))] <- countrain
         train_test_table[p, clen + which(cl %in% names(countest))] <- countest
       }
-      if(biomod2){ # creating a biomod2 data.split.table for validation
+      if(biomod2){ # creating a biomod2 CV.user.table for validation
         colm <- paste0("RUN", p)
         biomod_table[, colm] <- FALSE
         biomod_table[train_set, colm] <- TRUE
